@@ -15,24 +15,12 @@ def get_version_dev_status(root):
     return module.__version_info__._get_dev_status()
 
 
-def get_requirements(root):
-    """Load list of dependencies."""
-
-    install_requires = []
-    with open(os.path.join(root, "requirements", "setup.txt")) as f:
-        for line in f:
-            if not line.startswith("#"):
-                install_requires.append(line.strip())
-    return install_requires
-
-
 class CustomMetadataHook(MetadataHookInterface):
     """Our metadata hook."""
 
     def update(self, metadata):
         """See https://ofek.dev/hatch/latest/plugins/metadata-hook/ for more information."""
 
-        metadata["dependencies"] = get_requirements(self.root)
         metadata["classifiers"] = [
             f"Development Status :: {get_version_dev_status(self.root)}",
             'Environment :: Console',
@@ -40,10 +28,11 @@ class CustomMetadataHook(MetadataHookInterface):
             'License :: OSI Approved :: MIT License',
             'Operating System :: OS Independent',
             'Programming Language :: Python :: 3',
-            'Programming Language :: Python :: 3.7',
             'Programming Language :: Python :: 3.8',
             'Programming Language :: Python :: 3.9',
             'Programming Language :: Python :: 3.10',
+            'Programming Language :: Python :: 3.11',
+            'Programming Language :: Python :: 3.12',
             'Topic :: Software Development :: Libraries :: Python Modules',
             'Typing :: Typed'
         ]
